@@ -11,6 +11,7 @@ use File::Find::Rule;
 use File::Type;
 use File::Temp qw(tempdir);
 use Vimana::Logger;
+use Vimana::Util;
 
 use Moose;
 
@@ -40,6 +41,7 @@ sub inspect_text_content {
 
 =cut
 
+
 sub run {
     my ( $self ) = @_;
 
@@ -47,12 +49,17 @@ sub run {
 
     if( $pkg->is_archive() ) {
         $logger->info('Archive type file');
-
         return $self->install_from_archive;
     }
     elsif( $pkg->is_text() ) {
         $logger->info('Text type file');
 
+        my $type = $self->inspect_text_content;
+        if ($type) {
+            $logger->info("Found script type: $type");
+            return $self->install_to($type);
+        }
+
         return $self->install_to( 'colors' )
             if $pkg->script_is('color scheme');
 
@@ -87,7 +94,6 @@ sub install_to {
 
 sub install_from_archive {
     my $self = shift;
-
     my $options = $self->options;
     my $pkg = $self->package;
 
@@ -107,28 +113,38 @@ sub install_from_archive {
     $logger->info("Extracting...") if $options->{verbose};
     $pkg->archive->extract( $out );  
 
-    my @subdirs = File::Find::Rule->file->in(  $out );
-
-    # XXX: check vim runtime path subdirs
-    $logger->info("Initializing vim runtime path...") if $options->{verbose};
-    $self->init_vim_runtime();
-
-    my $nodes = $self->find_runtime_node( \@subdirs );
-
-    unless ( keys %$nodes ) {
-        $logger->warn("Can't found base path.");
-        return 0;
-    }
-    
-    if( $options->{verbose} ) {
-        $logger->info('base path:');
-        $logger->info( $_ ) for ( keys %$nodes );
+    if( $pkg->has_vimball() ) {
+        $logger->info( "I found vimball files inside the archive file , trying to install vimballs");
+        use Vimana::VimballInstall;
+        my @vimballs = File::Find::Rule->file->name( "*.vba" )->in( $out );
+        Vimana::VimballInstall->install_vimballs( @vimballs );
     }
 
-    $self->install_from_nodes( $nodes , runtime_path() );
+    # check directory structure
+    {
 
-    $logger->info("Updating helptags");
-    $self->update_vim_doc_tags();
+        # XXX: check vim runtime path subdirs , mv to init script
+        $logger->info("Initializing vim runtime path...") if $options->{verbose};
+        Vimana::Util::init_vim_runtime();
+
+        my @files = File::Find::Rule->file->in(  $out );
+        my $nodes = $self->find_base_path( \@files );
+
+        unless ( keys %$nodes ) {
+            $logger->warn("Can't found base path.");
+            return 0;
+        }
+        
+        if( $options->{verbose} ) {
+            $logger->info('base path:');
+            $logger->info( $_ ) for ( keys %$nodes );
+        }
+
+        $self->install_from_nodes( $nodes , runtime_path() );
+
+        $logger->info("Updating helptags");
+        $self->update_vim_doc_tags();
+    }
 
     $logger->info("Clean up temporary directory.");
     rmtree [ $out ] if -e $out;
@@ -136,31 +152,8 @@ sub install_from_archive {
     return 1;
 }
 
-=head2 runtime_path
-
-You can export enviroment variable VIMANA_RUNTIME_PATH to override default
-runtime path.
-
-=cut
-
-sub runtime_path {
-    # return File::Spec->join( $ENV{HOME} , 'vim-test' );
-    return $ENV{VIMANA_RUNTIME_PATH} || File::Spec->join( $ENV{HOME} , '.vim' );
-}
 
 
-=head2 init_vim_runtime 
-
-=cut
-
-sub init_vim_runtime {
-    my $self = shift;
-    my $paths = [ ];
-    for my $subdir ( qw(plugin doc syntax colors after ftplugin indent autoload) ) {
-        push @$paths ,File::Spec->join( runtime_path , $subdir );
-    }
-    mkpath $paths;
-}
 
 =head2 install_from_nodes
 
@@ -189,11 +182,11 @@ sub i_know_what_to_do {
 }
 
 
-=head2 find_runtime_node 
+=head2 find_base_path 
 
 =cut
 
-sub find_runtime_node {
+sub find_base_path {
     my ( $self, $paths ) = @_;
     my $nodes = {};
     for my $p ( @$paths ) {
@@ -204,10 +197,10 @@ sub find_runtime_node {
     return $nodes;
 }
 
-
 sub update_vim_doc_tags {
+    my $vim = find_vim();
     my $dir = File::Spec->join( runtime_path() , 'doc' );
-    system(qq| vim -c ':helptags $dir'  -c q |);
+    system(qq|$vim -c ':helptags $dir'  -c q |);
 }
 
 
